﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using SciChart.Charting.Model;
using SciChart.Charting.Numerics.DeltaCalculators;

namespace ulongAxisValues
{
    public class LongDeltaCalculator : IDeltaCalculator
    {
        public IAxisDelta GetDeltaFromRange(IComparable min, IComparable max, int minorsPerMajor, uint maximumTicks)
        {
            long minTicks = (long)min;
            long maxTicks = (long)max;
            ulong major = (ulong)CalculateGridPerDivisionTicks(minTicks, maxTicks, maximumTicks);
            return new UlongAxisDelta(major, minor: 0);
        }
        public static long CalculateGridPerDivisionTicks(double min, double max, double numberOfGridLines)
        {
            // Calculate an initial guess at step size
            double idealStep = (max - min) / numberOfGridLines;

            // Get the magnitude of the step size
            double magnitudeExponent = Math.Floor(Math.Log10(idealStep));
            double magnitude = Math.Pow(10, magnitudeExponent);

            // Calculate most significant digit of the new step size
            double magMsd = (int)Math.Round(idealStep / magnitude);

            // promote the MSD to either 2, 5, or 10
            if (magMsd > 5.0)
            {
                magMsd = 10.0f;
            }
            else if (magMsd > 2.0)
            {
                magMsd = 5.0f;
            }
            else if (magMsd > 1.0)
            {
                magMsd = 2.0f;
            }

            return (long)(magMsd * magnitude);
        }
    }

    public class UlongAxisDelta : IAxisDelta, IAxisDelta<ulong>
    {
        public UlongAxisDelta(ulong major, ulong minor)
        {
            _major = major;
            _minor = minor;
        }

        public IComparable MajorDelta => _major;

        ulong IAxisDelta<ulong>.MinorDelta
        {
            get { return _minor; }
            set { _minor = value; }
        }

        ulong IAxisDelta<ulong>.MajorDelta
        {
            get { return _major; }
            set { _major = value; }
        }

        public IComparable MinorDelta => _minor;

        public object Clone()
        {
            return new UlongAxisDelta(_major, _minor);
        }

        private ulong _major;
        private ulong _minor;
    }
}
