﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using SciChart.Charting.Model;
using SciChart.Charting.Model.DataSeries;
using SciChart.Charting.Numerics.DeltaCalculators;
using SciChart.Charting.Numerics.TickProviders;
using SciChart.Charting.Services;
using SciChart.Charting.Visuals.Axes;
using SciChart.Charting.Visuals.PointMarkers;
using SciChart.Charting.Visuals.RenderableSeries;
using SciChart.Data.Model;

namespace ulongAxisValues
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            AddData<ulong>();

            Chart.ZoomExtents();
        }

        private void AddData<T>() where T: IComparable
        {
            var data = SinusoidalData<T>(60);
            var series = new FastLineRenderableSeries() { DataSeries = data, XAxis = TimeAxis, YAxis = ValueAxis };
            series.AntiAliasing = true;
            series.Stroke = Colors.Red;
            series.PointMarker = new EllipsePointMarker();
            Chart.RenderableSeries.Add(series);
        }

        public const int NumberOfPoints = 2000;
        public static int SampleRate = 10000;

        public static long DateNanosOffset = new DateTime(2017, 1, 1, 1,1, 1).Ticks*100;

        private XyDataSeries<T, double> SinusoidalData<T>(int frequency) where T: IComparable
        {
            XyDataSeries<T, double> data = new XyDataSeries<T, double>();
            for (int i = 0; i < NumberOfPoints; i++)
            {
                T timeValue = (T) (dynamic) (((i / (double) SampleRate) * 1E9) + DateNanosOffset);
                data.Append(timeValue,
                    Math.Sin(2 * Math.PI * frequency * i / SampleRate));
            }
            return data;
        }
    }
}
